@@ -1,16 +1,9 @@
-import sys
 import platform
 
 import cairo
 import pytest
 
 
-try:
-    long
-except NameError:
-    long = int
-
-
 @pytest.fixture
 def font_options():
     surface = cairo.ImageSurface(0, 10, 10)
@@ -30,6 +23,25 @@ def scaled_font(font_face, font_options):
         font_face, cairo.Matrix(), cairo.Matrix(), font_options)
 
 
+@pytest.mark.skipif(not hasattr(cairo.FontOptions, "get_variations"),
+                    reason="too old cairo")
+def test_font_options_variations(font_options):
+    assert font_options.get_variations() is None
+    font_options.set_variations("foo")
+    assert font_options.get_variations() == "foo"
+    font_options.set_variations(None)
+    assert font_options.get_variations() is None
+
+    with pytest.raises(TypeError):
+        font_options.set_variations(1)
+
+    with pytest.raises(TypeError):
+        font_options.set_variations("foo", "bar")
+
+    with pytest.raises(TypeError):
+        font_options.set_variations()
+
+
 def test_font_options():
     assert isinstance(cairo.FontOptions(), cairo.FontOptions)
     with pytest.raises(TypeError):
@@ -54,7 +66,7 @@ def test_font_options_hash():
     surface = cairo.ImageSurface(cairo.FORMAT_RGB24, 1, 1)
     font_options = surface.get_font_options()
     assert font_options.hash() == font_options.hash()
-    assert isinstance(font_options.hash(), long)
+    assert isinstance(font_options.hash(), int)
 
 
 def test_font_options_merge():
@@ -83,9 +95,8 @@ def test_font_options_hashable_protocol():
     assert font_options != object()
 
     # make sure the other operators are undefined
-    if sys.version_info[0] == 3:
-        with pytest.raises(TypeError):
-            font_options < font_options
+    with pytest.raises(TypeError):
+        font_options < font_options
     assert font_options.__gt__(font_options) is NotImplemented
 
 
@@ -167,6 +178,7 @@ def test_scaled_font_get_scale_matrix(scaled_font):
     assert isinstance(scaled_font.get_scale_matrix(), cairo.Matrix)
 
 
+# https://bitbucket.org/pypy/pypy/issues/2741
 @pytest.mark.skipif(platform.python_implementation() == "PyPy", reason="PyPy")
 def test_scaled_font_text_extents(scaled_font):
     with pytest.raises(TypeError):
@@ -182,6 +194,7 @@ def test_scaled_font_glyph_extents(scaled_font):
         scaled_font.glyph_extents()
 
 
+# https://bitbucket.org/pypy/pypy/issues/2741
 @pytest.mark.skipif(platform.python_implementation() == "PyPy", reason="PyPy")
 def test_toy_font_face():
     with pytest.raises(TypeError):
